import requests
import json

def _request_details(id):
    try:
        url = f"https://gateway.bdjobs.com/ActtivejobsTest/api/JobSubsystem/jobDetails?jobId={id}"
        response = requests.get(url)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            raise ValueError(response.status_code)
    except Exception as e:
            return {"error": f"Failed to fetch.", "desc": str(e)}



from .parse_id import _parse_id
from .request_details import _request_details
from .clean_html import _clean_html

def scrape_by_url(url:str)-> str:
    try:
        parsed = _parse_id(url)
        if parsed["error"]:
            raise ValueError(parsed["error"])

        job_id = parsed["id"]
        job_details = _request_details(job_id)
        if job_details.get("statuscode") == "0" and job_details.get("data"):
            fields_to_clean = [
                "JobDescription",
                "EducationRequirements",
                "experience",
                "AdditionJobRequirements",
                "JobOtherBenifits",
                "JobKeyPoints",
                "ApplyInstruction",
            ]

            first_job = job_details["data"][0]

            for field in fields_to_clean:
                if field in first_job and first_job[field]:
                    first_job[field] = _clean_html(str(first_job[field]))
            return first_job
        else:
            raise ValueError(f"Failed to retrieve job details for ID {job_id}")
    except Exception as e:
        return {"error": e}



from urllib.parse import urlparse, parse_qs
def _parse_id(url):
    parsed_url = urlparse(url)
    try:
        if not parsed_url.netloc.endswith('bdjobs.com'):
            raise ValueError("Not a bdjobs.com URL")
        if not parsed_url.path.startswith('/jobdetails'):
            raise ValueError("Not a job details URL")
        query_params = parse_qs(parsed_url.query)
        id = query_params.get("id", [None])[0]
        if id is None:
            raise ValueError("Missing 'id' query parameter")
        return {"id": id, "error": None}
    except Exception as e:
        return {"id": None, "error": str(e)}


from bs4 import BeautifulSoup


def _clean_html(value: str) -> str:
    if not value:
        return ""
    soup = BeautifulSoup(value, "html.parser")
    return soup.get_text(separator=" ", strip=True)